@@ -1,6 +1,6 @@
 /*
  * xdx - GTK+ DX-cluster client for amateur radio
- * Copyright (C) 2002-2003 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2002-2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -46,12 +46,42 @@ typedef struct
   gchar *rigctl;
   gchar *browserapp;
   gchar *mailapp;
+  gchar *soundapp;
   gint col0visible;
   gint col1visible;
   gint col2visible;
   gint col3visible;
   gint col4visible;
   gint col5visible;
+  gchar *dxfont;
+  gchar *allfont;
+  gint localecho;
+  gint handlebarpos;
+  gchar *highword1;
+  gchar *highword2;
+  gchar *highword3;
+  gchar *highword4;
+  gchar *highword5;
+  gchar *highword6;
+  gchar *highword7;
+  gchar *highword8;
+  GdkColor highcolor1;
+  GdkColor highcolor2;
+  GdkColor highcolor3;
+  GdkColor highcolor4;
+  GdkColor highcolor5;
+  GdkColor highcolor6;
+  GdkColor highcolor7;
+  GdkColor highcolor8;
+  gchar *highmenu;
+  gint sidebar;
+  gint reconnect;
+  gint playsound;
+  gint keepalive;
+  GdkColor promptcolor;
+  GdkColor sentcolor;
+  GdkColor wwvcolor;
+  GdkColor wxcolor;
 } preferencestype;
 
 void dircheck (void);
